@@ -78,6 +78,21 @@ def parse_args(args):
         type=str,
         help="the path to the image to be used as the album cover (defaults to using the thumbnail of the first video in the playlist). Only works when -A flag is set",
     )
+    parser.add_argument(
+        "-p",
+        "--proxy",
+        type=str,
+        help="list of proxies to use. Must be enclosed in string quotes with a space separating each proxy. Proxy format: <protocol>-<proxy>",
+    )
+    parser.add_argument(
+        "-3",
+        "--mp3",
+        type=bool,
+        nargs="?",
+        const=True,
+        default=False,
+        help="converts downloaded files to mp3 format and deletes original mp4 file",
+    )
     return parser.parse_args(args)
 
 def main():
@@ -92,7 +107,17 @@ def main():
     album = playlist_title if args.album is None else args.album
     directory = "music/" if args.directory is None else args.directory
     artist = "Unknown" if args.artist is None else args.artist
-    is_album = False if args.album is None else True 
+    is_album = False if args.album is None else True
+
+    proxies = None
+    if args.proxy is not None:
+        proxy_strings = [proxy.strip() for proxy in args.proxy.split(" ")]
+        proxies = {}
+        for proxy_string in proxy_strings:
+            p = proxy_string.split('-')
+            proxies[p[0]] = p[1]
+
+
 
     try:
         if start >= len(urls):
@@ -103,7 +128,7 @@ def main():
         downloading_message = f"Downloading songs {font.apply('gb', start+1)} - {font.apply('gb', end)} from playlist {font.apply('gb', playlist_title)}"
         text_len = len("Downloading songs ") + len(str(start)) + len(" - ") + len(str(end)) + len(" from playlist ") + len(playlist_title) 
         print(downloading_message, f"\n{font.apply('gb', '─'*text_len)}")
-        d = Downloader(urls[start:end], album, directory, artist, is_album, args.titles, args.image)
+        d = Downloader(enumerate(urls[start:end]), len(urls), album, directory, artist, is_album, args.titles, args.image, proxies, args.mp3)
         d.start = start
 
         retry = True
@@ -135,4 +160,9 @@ def main():
         print(f"Error: {e.message}")
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
+
+#https-socks5://98.162.96.41:4145
+#https://18.140.249.11:80
+#https://www.youtube.com/playlist?list=PLOoPqX_q5JAUSng1aEWmEC1Q4E0EJnPts
+# short PL with one 10sec video: https://www.youtube.com/playlist?list=PLOoPqX_q5JAVEgR2bv8MxS9RFgxJPEoCv
\ No newline at end of file
